import { fs, chokidar, Subject, jsYaml } from './libs';
export async function findClosestAncestor(startDir, fileName) {
    const find = async (dir) => {
        if (!dir || dir === '/') {
            return;
        }
        const path = fs.join(dir, fileName);
        return (await fs.pathExists(path)) ? path : find(fs.resolve(dir, '..'));
    };
    return find(startDir);
}
export function watch(pattern) {
    const subject = new Subject();
    chokidar.watch(pattern).on('change', (path) => subject.next(path));
    return subject.asObservable();
}
export async function yaml(filePath) {
    let path = '';
    const subpath = filePath.substring(0, filePath.length - fs.extname(filePath).length);
    const setIfExists = async (ext) => {
        if (path) {
            return;
        }
        const test = `${subpath}${ext}`;
        path = (await fs.pathExists(test)) ? test : path;
    };
    await setIfExists('.yml');
    await setIfExists('.yaml');
    try {
        const text = (await fs.readFile(path)).toString();
        const res = jsYaml.safeLoad(text);
        return res;
    }
    catch (error) {
        throw new Error(`Failed to load YAML file '${filePath}'. ${error.message}`);
    }
}
