import command from './command';
import { R, fs } from './common';
function toCommand(modulePath) {
    const m = require(modulePath);
    let name;
    name = m.name ? m.name : fs.basename(modulePath, '.js');
    name = name.endsWith('.cmd') ? fs.basename(name, '.cmd') : name;
    let alias = m.alias;
    if (!R.is(Array, alias)) {
        alias = [alias];
    }
    alias = R.reject(R.isNil)(alias);
    const action = m.cmd || m.default;
    return {
        name,
        alias,
        description: m.description,
        group: m.group,
        args: m.args,
        validate: m.validate,
        action: action,
    };
}
function toCommands(modulePaths) {
    const commands = modulePaths
        .map(toCommand)
        .filter(item => R.is(Function, item.action));
    const result = {};
    commands.forEach(cmd => (result[cmd.name] = cmd));
    return result;
}
async function pathToCommands(path) {
    const paths = await fs.glob.find(path);
    return toCommands(paths);
}
export default async (param) => {
    if (typeof param === 'string') {
        param = await pathToCommands(param);
    }
    if (Array.isArray(param)) {
        let out = {};
        for (const path of param) {
            out = Object.assign(Object.assign({}, out), (await pathToCommands(path)));
        }
        param = out;
    }
    command(param);
};
